% Estimates a good exposure time sequence for sampling a HDR scene
% in a way that a minimum SNR is obtained at every pixel.
%
% The script was used to generate the results reported in the paper:
%
% Optimal HDR reconstruction with linear digital cameras
% M. Granados, B. Ajdin, M. Wand, C. Theobalt, H.-P. Seidel, H. P. A. Lensch
% In Proc. IEEE Conf. Comp. Vis. Pat. Rec. (CVPR), 
%   June 13-18, 2010, San Francisco, USA
%
% Author: Miguel Granados, MPI Informatik, 2011

more off

% load camera parameters
cam = cams5_400;

% load scene irradiance
[R, G, B] = pfs_read_rgb('s5test2v1.pfs');

% set the estimation parameters
recon.X.mu = B(1:4:end, 1:4:end); % use subsampled blue channel as input
recon.tsnr0 = 32; % set target SNR
recon.nt = 24; % set maximum number of exposures

% estimate optimal exposure sequence
recon = dotopt(cam, recon);
t = recon.t; % estimated exposure sequence